@@ -1,53 +1,8 @@
 package App::gh;
 use warnings;
 use strict;
-use Exporter::Lite;
 
-our $VERSION = '0.236';
-
-our @EXPORT = qw(parse_config parse_options get_github_auth);
-
-sub parse_config {
-    my ($file) = @_;
-    open FH , "<" , $file;
-    local $/;
-    my $content = <FH>;
-    close FH;
-    my @parts = split /(?=\[.*?\])/,$content;
-
-
-    my %config;
-
-    for my $part ( @parts ) {
-        if( $part =~ /^\[(\w+)\s+["'](\w+)["']\]/g ) {
-            my ($o1 , $o2 ) = ($1, $2);
-            $config{ $o1 } ||= {};
-            $config{ $o1 }->{ $o2 } 
-                = parse_options( $part );
-        }
-        elsif( $part =~ /^\[(.*?)\]/g  ) {
-            my $key = $1;
-            my $options = parse_options( $part );
-            $config{ $key } = $options;
-        }
-    }
-    return \%config;
-}
-
-sub parse_options {
-    my $part = shift;
-    my $options;
-    while(  $part =~ /^\s*(.*?)\s*=\s*(.*?)\s*$/gm ) {
-        my ($name,$value) = ($1,$2);
-        $options->{ $name } = $value;
-    }
-    return $options;
-}
-
-sub get_github_auth {
-    my $config = parse_config $ENV{HOME} . "/.gitconfig";
-    return $config->{github};
-}
+our $VERSION = '0.24';
 
 __END__
 
